==> forms-7.1.10-sources.jar: com/itextpdf/forms/xfdf/AnnotsObject.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2020 iText Group NV
    Authors: iText Software.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/

    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.

    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.

    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.

    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.forms.xfdf;

import java.util.ArrayList;
import java.util.List;

/**
 * Represent annots tag in xfdf document structure.
 * Content model: ( text | caret | freetext | fileattachment | highlight | ink | line | link
 * | circle | square | polygon | polyline | sound | squiggly | stamp |
 * strikeout | underline )*.
 * Attributes: none.
 * For more details see paragraph 6.4.1 in Xfdf specification.
 */
public class AnnotsObject {

    /**
     * Represents a list of children annotations.
     */
    private List<AnnotObject> annotsList;

    public AnnotsObject() {
        annotsList = new ArrayList<>();
    }

    /**
     * Gets a list of children annotations.
     */
    public List<AnnotObject> getAnnotsList() {
        return annotsList;
    }

    /**
     * Adds a new {@link AnnotObject} to the list of children annotations.
     * @param annot {@link AnnotObject} containing info about pdf document annotation.
     */
    public AnnotsObject addAnnot(AnnotObject annot) {
        this.annotsList.add(annot);
        return this;
    }
}

==> forms-7.1.12-sources.jar: com/itextpdf/forms/xfdf/AnnotsObject.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2020 iText Group NV
    Authors: iText Software.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/

    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.

    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.

    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.

    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.forms.xfdf;

import java.util.ArrayList;
import java.util.List;

/**
 * Represent annots tag in xfdf document structure.
 * Content model: ( text | caret | freetext | fileattachment | highlight | ink | line | link
 * | circle | square | polygon | polyline | sound | squiggly | stamp |
 * strikeout | underline )*.
 * Attributes: none.
 * For more details see paragraph 6.4.1 in Xfdf specification.
 */
public class AnnotsObject {

    /**
     * Represents a list of children annotations.
     */
    private List<AnnotObject> annotsList;

    /**
     * Creates an instance with the empty list of children annotations.
     */
    public AnnotsObject() {
        annotsList = new ArrayList<>();
    }

    /**
     * Gets children annotations.
     * @return a {@link List} of {@link AnnotObject} each representing a child annotation of this annots tag.
     */
    public List<AnnotObject> getAnnotsList() {
        return annotsList;
    }

    /**
     * Adds a new {@link AnnotObject} to the list of children annotations.
     * @param annot {@link AnnotObject} containing info about pdf document annotation.
     * @return this {@link AnnotsObject} instance.
     */
    public AnnotsObject addAnnot(AnnotObject annot) {
        this.annotsList.add(annot);
        return this;
    }
}
